@@ -1,4 +1,4 @@
-# $Id: Lambda.pm,v 1.188 2010/04/06 10:56:02 dk Exp $
+# $Id: Lambda.pm,v 1.191 2012/01/13 06:41:28 dk Exp $
 package IO::Lambda;
 
 use Carp qw(croak);
@@ -16,7 +16,7 @@ use vars qw(
 	$THIS @CONTEXT $METHOD $CALLBACK $AGAIN $SIGTHROW
 	$DEBUG_IO $DEBUG_LAMBDA $DEBUG_CALLER %DEBUG
 );
-$VERSION     = '1.20';
+$VERSION     = '1.26';
 @ISA         = qw(Exporter);
 @EXPORT_CONSTANTS = qw(
 	IO_READ IO_WRITE IO_EXCEPTION 
@@ -809,7 +809,8 @@ sub backtrace
 sub add_watch
 {
 	my ($self, $cb, $method, $flags, $handle, $deadline, @ctx) = @_;
-	my $who = (caller(1))[3] if $DEBUG_CALLER;
+	my $who;
+	$who = (caller(1))[3] if $DEBUG_CALLER;
 	$self-> watch_io(
 		$flags, $handle, $deadline,
 		sub {
@@ -864,7 +865,8 @@ sub writable(&)
 sub add_timer
 {
 	my ($self, $cb, $method, $deadline, @ctx) = @_;
-	my $who = (caller(1))[3] if $DEBUG_CALLER;
+	my $who;
+	$who = (caller(1))[3] if $DEBUG_CALLER;
 	$self-> watch_timer(
 		$deadline,
 		sub {
@@ -891,7 +893,8 @@ sub timeout(&)
 sub add_tail
 {
 	my ($self, $cb, $method, $lambda, @ctx) = @_;
-	my $who = (caller(1))[3] if $DEBUG_CALLER;
+	my $who;
+	$who = (caller(1))[3] if $DEBUG_CALLER;
 	$self-> watch_lambda(
 		$lambda,
 		($cb ? sub {
@@ -1201,7 +1204,7 @@ sub sysreader (){ lambda
 		my $n = sysread( $fh, $$buf, $length, length($$buf));
 		if ( $DEBUG_IO) {
 			warn "fh(", fileno($fh), ") read ", ( defined($n) ? "$n bytes" : "error $!"), "\n";
-			warn substr( $$buf, length($$buf) - $n), "\n" if $DEBUG_IO > 1 and $n > 0;
+			warn substr( $$buf, length($$buf) - $n), "\n" if $DEBUG_IO > 1 and ($n || 0) > 0;
 		}
 		return undef, $! unless defined $n;
 		return $n;
@@ -1221,7 +1224,7 @@ sub syswriter (){ lambda
 		my $n = syswrite( $fh, $$buf, $length, $offset);
 		if ( $DEBUG_IO) {
 			warn "fh(", fileno($fh), ") wrote ", ( defined($n) ? "$n bytes out of $length" : "error $!"), "\n";
-			warn substr( $$buf, $offset, $n), "\n" if $DEBUG_IO > 1 and $n > 0;
+			warn substr( $$buf, $offset, $n), "\n" if $DEBUG_IO > 1 and ($n || 0) > 0;
 		}
 		return undef, $! unless defined $n;
 		return $n;
@@ -2132,7 +2135,7 @@ Example: convert existing C<getline> constructor into a condition:
 
 =head2 Stream IO
 
-The whole point of this module is to help building protocols or arbitrary
+The whole point of this module is to help building protocols of arbitrary
 complexity in a clear, consequent programming style. Consider how perl's
 low-level C<sysread> and C<syswrite> relate to its higher-level C<readline>,
 where the latter not only does the buffering, but also recognizes C<$/> as
@@ -2738,7 +2741,7 @@ L<IO::Lambda::Socket> - lambda versions of C<connect>, C<accept> etc.
 
 L<IO::Lambda::HTTP> - implementation of HTTP and HTTPS protocols.  HTTPS
 requires L<IO::Socket::SSL>, NTLM/Negotiate authentication requires
-L<Authem::NTLM> modules (not marked as dependencies).
+L<Authen::NTLM> modules (not marked as dependencies).
 
 =item *
 
@@ -2857,16 +2860,15 @@ See benchmarking code in F<eg/bench>.
 =head2 Apologetics
 
 There are many async libraries readily available from CPAN. C<IO::Lambda> is
-yet another one. How is it different from the existing tools? Why using it?  To
+yet another one. How is it different from the existing tools? Why use it?  To
 answer these questions, I need to show the evolution of async libraries, to
 explain how they grew from simple tools to complex frameworks.
 
 First, all async libraries are based on OS-level syscalls, like C<select>,
 C<poll>, C<epoll>, C<kqueue>, and C<Win32::WaitForMultipleObjects>. The first
-layer of async libraries provides access to exactly these facilites: there are
-C<IO::Select>, C<IO::Epoll>, C<IO::Kqueue> etc. I won't go deepeer into
-describing pros and contras for programming on this level, this should be
-obvious.
+layer provides access to exactly these facilities: there are C<IO::Select>,
+C<IO::Epoll>, C<IO::Kqueue> etc. I won't go deeper into describing pros and
+cons for programming on this level, this should be obvious.
 
 Perl modules of the next abstraction layer are often characterised by
 portability and event loops. While the modules of the first layer are seldom
@@ -2875,7 +2877,7 @@ OS-independent, and use callbacks to ease the otherwise convoluted ways async
 I/O would be programmed. These modules mostly populate the "asynchronous
 input-output programming frameworks" niche in the perl world. The examples are
 many: C<IO::Events>, C<EV>, C<AnyEvent>, C<IO::NonBlocking>, C<IO::Multiplex>,
-to name the few. 
+to name a few. 
 
 Finally, there's the third layer of complexity, which, before C<IO::Lambda>,
 had a single representative: C<POE> (now, to the best of my knowledge,
@@ -2907,7 +2909,7 @@ Consider C<POE> code:
 	   },
    });
 
-and the correspodning C<IO::Lambda> code (I<state1> and I<state2> are I<conditions>,
+and the corresponding C<IO::Lambda> code (I<state1> and I<state2> are I<conditions>,
 they need to be declared separately):
 
     lambda {
